<?php

/**
 * @file
 * Administrative callbacks for the AdSense Content module.
 */

/**
 * Creates the form components for a settings page.
 */
function _adsense_consent_admin_settings($form, &$form_state) {
  $form = array();
  $form['AdSense Account'] = array(
    '#type' => 'fieldset',
    '#title' => t('AdSense Account Settings'),
    '#collapsible' => FALSE,
  );
  $form['AdSense Account']['adsense_consent_pubid'] = array(
    '#type' => 'textfield',
    '#title' => t('Publisher ID'),
    '#default_value' => variable_get('adsense_consent_pubid', ""),
    '#description' => t('The AdSense publisher ID, of the form pub-9999...'),
    '#required' => TRUE,
  );
  $form['AdSense Global'] = array(
    '#type' => 'fieldset',
    '#title' => t('Global Settings'),
    '#collapsible' => FALSE,
    '#description' => t('Enable Page Ads for things like interstitial, anchor, vignette and auto ads. Exact ads are controlled within your AdSense account.'),
  );
  $form['AdSense Global']['adsense_consent_page_ads'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Page Ads'),
    '#default_value' => variable_get('adsense_consent_page_ads', FALSE),
    '#description' => t('Do you want to show Page Ads'),
  );
  $desc = '<p>Settings for the block you can use to display an ad unit.</p>' .
      '<p>If you only wish to show one ad unit in the block, enter the ID for that unit under Slot A, with a proportion of 1. <br />' .
      'If you wish to rotate 2 or 3 different ad units, put the alternative ad unit(s) IDs under slots B (and C), with proportions to ' .
      'indicate the relative frequency with which they will appear.';
  $form['AdSense Block'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block Settings'),
    '#collapsible' => TRUE,
    '#description' => $desc,
  );
  $desc = 'If you want a Drupal block to display ads, you need to enter the ID of the Ad Unit to display. ' .
    'If you leave Slot A blank, no block will be created, but page-level ads will still work if enabled under Global Settings.';
  $form['AdSense Block']['AdSense A'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#title' => t('Ad Slot A'),
    '#description' => $desc,
  );
  $form['AdSense Block']['AdSense A']['adsense_consent_account_a'] = array(
    '#type' => 'textfield',
    '#title' => t('Ad Unit ID'),
    '#default_value' => variable_get('adsense_consent_account_a', ""),
    '#description' => t('The ID of the Ad Unit to use in this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense A']['adsense_consent_proportion_a'] = array(
    '#type' => 'textfield',
    '#title' => t('Proportion'),
    '#element_validate' => array('element_validate_integer_positive'),
    '#default_value' => variable_get('adsense_consent_proportion_a', ""),
    '#description' => t('The proportion of pages that will show this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense A']['adsense_consent_title_a'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => variable_get('adsense_consent_title_a', ""),
    '#description' => t('Title of block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense A']['adsense_consent_cssclass_a'] = array(
    '#type' => 'textfield',
    '#title' => t('CSS Class'),
    '#default_value' => variable_get('adsense_consent_cssclass_a', ""),
    '#description' => t('CSS Class to add to block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense B'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Ad Slot B'),
  );
  $form['AdSense Block']['AdSense B']['adsense_consent_account_b'] = array(
    '#type' => 'textfield',
    '#title' => t('Ad Unit ID'),
    '#default_value' => variable_get('adsense_consent_account_b', ""),
    '#description' => t('The ID of the Ad Unit to use in this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense B']['adsense_consent_proportion_b'] = array(
    '#type' => 'textfield',
    '#title' => t('Proportion'),
    '#element_validate' => array('element_validate_integer_positive'),
    '#default_value' => variable_get('adsense_consent_proportion_b', ""),
    '#description' => t('The proportion of pages that will show this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense B']['adsense_consent_title_b'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => variable_get('adsense_consent_title_b', ""),
    '#description' => t('Title of block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense B']['adsense_consent_cssclass_b'] = array(
    '#type' => 'textfield',
    '#title' => t('CSS Class'),
    '#default_value' => variable_get('adsense_consent_cssclass_b', ""),
    '#description' => t('CSS Class to add to block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense C'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Ad Slot C'),
  );
  $form['AdSense Block']['AdSense C']['adsense_consent_account_c'] = array(
    '#type' => 'textfield',
    '#title' => t('Ad Unit ID'),
    '#default_value' => variable_get('adsense_consent_account_c', ""),
    '#description' => t('The ID of the Ad Unit to use in this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense C']['adsense_consent_proportion_c'] = array(
    '#type' => 'textfield',
    '#title' => t('Proportion'),
    '#element_validate' => array('element_validate_integer_positive'),
    '#default_value' => variable_get('adsense_consent_proportion_c', ""),
    '#description' => t('The proportion of pages that will show this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense C']['adsense_consent_title_c'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => variable_get('adsense_consent_title_c', ""),
    '#description' => t('Title of block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Block']['AdSense C']['adsense_consent_cssclass_c'] = array(
    '#type' => 'textfield',
    '#title' => t('CSS Class'),
    '#default_value' => variable_get('adsense_consent_cssclass_c', ""),
    '#description' => t('CSS Class to add to block when using this variation.'),
    '#required' => FALSE,
  );
  $form['AdSense Consent Page'] = array(
    '#type' => 'fieldset',
    '#title' => t('AdSense Consent Page Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => t('Control <a href="/ad-options">the page</a> where users can indicate their consent to personalised ads.'),
  );
  $form['AdSense Consent Page']['adsense_consent_wait'] = array(
    '#type' => 'fieldset',
    '#title' => t('Require explicit consent before showing any ads'),
    '#collapsible' => FALSE,
    '#description' => t('If the checkboxes below are all cleared, ads will be shown immediately. If any checkboxes are checked, visitors must give consent before ads will be shown, using any of the methods checked.'),
  );
  $form['AdSense Consent Page']['adsense_consent_wait']['adsense_consent_wait_consent'] = array(
    '#type' => 'checkbox',
    '#title' => t('Require explicit consent from <a href="/ad-options">ad options page</a>.'),
    '#default_value' => variable_get('adsense_consent_wait_consent', ""),
  );
  $form['AdSense Consent Page']['adsense_consent_wait']['adsense_consent_wait_eu_cookie_compliance'] = array(
    '#type' => 'checkbox',
    '#title' => t('Require explicit consent from <a href="https://www.drupal.org/project/eu_cookie_compliance">EU Cookie Compliance module</a>.'),
    '#default_value' => variable_get('adsense_consent_wait_eu_cookie_compliance', ""),
  );
  if (!module_exists('eu_cookie_compliance')) {
    $form['AdSense Consent Page']['adsense_consent_wait']['adsense_consent_wait_eu_cookie_compliance']['#attributes']['disabled'] = 'disabled';
  }
  $form['AdSense Consent Page']['adsense_consent_personalise'] = array(
    '#type' => 'radios',
    '#title' => t('Personalise Ads'),
    '#default_value' => variable_get('adsense_consent_personalise', 1),
    '#options' => array(
      0 => t('Show non-personalised ads all the time'),
      1 => t('Show personalised ads unless a visitor has opted out'),
      2 => t('Show non-personalised ads unless a visitor opts in'),
    ),
  );
  $form['AdSense Consent Page']['adsense_consent_providers'] = array(
    '#type' => 'textarea',
    '#title' => t('Technology Providers'),
    '#default_value' => variable_get('adsense_consent_providers', ""),
    '#description' => t('List of all the AdSense Technology Providers used. Value should be a list of comma separated pairs: provider,url'),
    '#required' => TRUE,
  );
  $text1 = variable_get('adsense_consent_page_text_personalise', '');
  if ($text1 == '') {
    $text1 = array(
      'format' => filter_fallback_format(),
      'value' => '',
    );
  }
  $form['AdSense Consent Page']['Personalised'] = array(
    '#type' => 'fieldset',
    '#title' => t('Text to display on consent page when visitors can decide whether to see personalised ads'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['AdSense Consent Page']['Not Personalised'] = array(
    '#type' => 'fieldset',
    '#title' => t('Text to display on consent page when personalised ads are always turned off'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['AdSense Consent Page']['Obtain Consent'] = array(
    '#type' => 'fieldset',
    '#title' => t('Text to display on consent page when consent is needed for ads'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['AdSense Consent Page']['Personalised']['adsense_consent_page_text_personalise'] = array(
    '#type' => 'text_format',
    '#title' => t('Text at the top of the consent page'),
    '#default_value' => $text1['value'],
    '#format' => $text1['format'],
    '#description' => '<em>' . t('(This text area does not work with some wysiwyg editors; you may have to disable rich-text to edit this setting.') . '</em>',
    '#required' => TRUE,
  );
  $text2 = variable_get('adsense_consent_page_text_no_personalise', '');
  if ($text2 == '') {
    $text2 = array(
      'format' => filter_fallback_format(),
      'value' => '',
    );
  }
  $form['AdSense Consent Page']['Not Personalised']['adsense_consent_page_text_no_personalise'] = array(
    '#type' => 'text_format',
    '#title' => t('Text at the top of the consent page'),
    '#default_value' => $text2['value'],
    '#format' => $text2['format'],
    '#description' => '<em>' . t('(This text area does not work with some wysiwyg editors; you may have to disable rich-text to edit this setting.') . '</em>',
    '#required' => TRUE,
  );
  $text3 = variable_get('adsense_consent_page_text_footer_p', '');
  if ($text3 == '') {
    $text3 = array(
      'format' => filter_fallback_format(),
      'value' => '',
    );
  }
  $form['AdSense Consent Page']['Personalised']['adsense_consent_page_text_footer_p'] = array(
    '#type' => 'text_format',
    '#title' => t('Text at the foot of the consent page'),
    '#default_value' => $text3['value'],
    '#format' => $text3['format'],
    '#description' => '<em>' . t('(This text area does not work with some wysiwyg editors; you may have to disable rich-text to edit this setting.') . '</em>',
    '#required' => FALSE,
  );
  $text4 = variable_get('adsense_consent_page_text_footer_no_p', '');
  if ($text4 == '') {
    $text4 = array(
      'format' => filter_fallback_format(),
      'value' => '',
    );
  }
  $form['AdSense Consent Page']['Not Personalised']['adsense_consent_page_text_footer_no_p'] = array(
    '#type' => 'text_format',
    '#title' => t('Text at the foot of the consent page'),
    '#default_value' => $text4['value'],
    '#format' => $text4['format'],
    '#description' => '<em>' . t('(This text area does not work with some wysiwyg editors; you may have to disable rich-text to edit this setting.') . '</em>',
    '#required' => FALSE,
  );
  $text5 = variable_get('adsense_consent_page_text_ask_consent', '');
  if ($text5 == '') {
    $text5 = array(
      'format' => filter_fallback_format(),
      'value' => '',
    );
  }
  $form['AdSense Consent Page']['Obtain Consent']['adsense_consent_page_text_ask_consent'] = array(
    '#type' => 'text_format',
    '#title' => t('Text to ask for consent if explicit consent is required and the ad options page is the place you obtain it'),
    '#default_value' => $text5['value'],
    '#format' => $text5['format'],
    '#description' => '<em>' . t('(This text area does not work with some wysiwyg editors; you may have to disable rich-text to edit this setting.') . '</em>',
    '#required' => FALSE,
  );
  $form['AdSense Consent Page']['Obtain Consent']['adsense_consent_page_consent_label'] = array(
    '#type' => 'textfield',
    '#title' => t('The label next to the "consent" checkbox'),
    '#default_value' => variable_get(adsense_consent_page_consent_label, t('Yes, I consent')),
    '#required' => FALSE,
  );
  $form['#validate'][] = '_adsense_consent_validate';
  return system_settings_form($form);
}

/**
 * Validate AdSense Consent settings form.
 */
function _adsense_consent_validate($form, &$form_state) {
  global $_adsense_consent_parse_reg;
  if (!preg_match('/^pub-[0-9]+$/', $form_state['values']['adsense_consent_pubid'])) {
    form_set_error('adsense_consent_pubid', t('A valid AdSense Publisher ID is case sensitive and formatted like %id.', array('%id' => 'pub-9999999999999')));
  }
  // We'll use this multiple times below, so keep code DRY.
  $slot_regex = '/^\d{10}$/';
  if ($form_state['values']['adsense_consent_account_a'] != '' && !preg_match($slot_regex, $form_state['values']['adsense_consent_account_a'])) {
    form_set_error('adsense_consent_account_a', t('A valid AdSense Slot ID is exactly 10 digits (0-9)'));
  }
  if ($form_state['values']['adsense_consent_account_b'] != '' && !preg_match($slot_regex, $form_state['values']['adsense_consent_account_b'])) {
    form_set_error('adsense_consent_account_b', t('A valid AdSense Slot ID is exactly 10 digits (0-9)'));
  }
  if ($form_state['values']['adsense_consent_account_c'] != '' && !preg_match($slot_regex, $form_state['values']['adsense_consent_account_c'])) {
    form_set_error('adsense_consent_account_c', t('A valid AdSense Slot ID is exactly 10 digits (0-9)'));
  }
  if ($form_state['values']['adsense_consent_account_a'] != '' && $form_state['values']['adsense_consent_proportion_a'] == '') {
    form_set_error('adsense_consent_proportion_a', t('All variations with an AdSense Slot ID must also specify a Proportion'));
  }
  if ($form_state['values']['adsense_consent_account_b'] != '' && $form_state['values']['adsense_consent_proportion_b'] == '') {
    form_set_error('adsense_consent_proportion_b', t('All variations with an AdSense Slot ID must also specify a Proportion'));
  }
  if ($form_state['values']['adsense_consent_account_c'] != '' && $form_state['values']['adsense_consent_proportion_c'] == '') {
    form_set_error('adsense_consent_proportion_c', t('All variations with an AdSense Slot ID must also specify a Proportion'));
  }
  $providers = preg_split('/\r\n/', $form_state['values']['adsense_consent_providers']);
  $provider_errors = "";
  foreach ($providers as $provider) {
    if ($provider != "" && preg_match($_adsense_consent_parse_reg, $provider) == 0) {
      $provider_errors .= check_plain($provider) . "<br />";
    }
  }
  if ($provider_errors != "") {
    form_set_error('adsense_consent_providers',
      t('The following lines in the provider list were not of the required format {<em>provider, url</em>}:<br />') . $provider_errors);
  }
  if (!filter_access(filter_format_load($form_state['values']['adsense_consent_page_text_personalise']['format']))) {
    form_set_error('adsense_consent_page_text_personalise', t('Invalid text format chosen'));
  }
  if (!filter_access(filter_format_load($form_state['values']['adsense_consent_page_text_no_personalise']['format']))) {
    form_set_error('adsense_consent_page_text_no_personalise', t('Invalid text format chosen'));
  }
  if (!filter_access(filter_format_load($form_state['values']['adsense_consent_page_text_footer_p']['format']))) {
    form_set_error('adsense_consent_page_text_footer_p', t('Invalid text format chosen'));
  }
  if (!filter_access(filter_format_load($form_state['values']['adsense_consent_page_text_footer_no_p']['format']))) {
    form_set_error('adsense_consent_page_text_footer_no_p', t('Invalid text format chosen'));
  }
  if (!filter_access(filter_format_load($form_state['values']['adsense_consent_page_text_ask_consent']['format']))) {
    form_set_error('adsense_consent_page_text_ask_consent', t('Invalid text format chosen'));
  }
}
